==> ejc-lz-api-3.0.0-20220530.013825-115-sources.jar: com/ejianc/business/base/bases/api/BaseApi.java <==
package com.ejianc.business.base.bases.api;

import com.ejianc.business.base.bases.hystrix.BaseHystrix;
import com.ejianc.business.base.bases.vo.MaterialVO;
import com.ejianc.business.base.bases.vo.ProductVO;
import com.ejianc.business.base.bases.vo.SettlementPerioddetailVO;
import com.ejianc.business.base.bases.vo.ShippersInfoApiVO;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;

@FeignClient(name= "ejc-lz-web", url="${common.env.feign-client-url}", path="ejc-lz-web", fallback = BaseHystrix.class)
public interface BaseApi {
    @PostMapping("/api/base/baseApi/getshippersinfo")
    CommonResponse<ShippersInfoApiVO> getShippersInfo(@RequestParam(value = "carCode") String carCode,@RequestParam(value = "orgId") Long orgId);
    @GetMapping("/api/base/baseApi/updatestatus")
    CommonResponse updatestatus(@RequestParam(value = "vehicleId") Long vehicleId,@RequestParam(value = "status") Integer status);
    @GetMapping(value = "/api/base/baseApi/querymaterialdetail")
    CommonResponse<MaterialVO> querymaterialdetail(Long id);
    @GetMapping(value = "/api/base/baseApi/queryproductdetail")
    CommonResponse<ProductVO> queryproductdetail(Long id);
    @PostMapping(value = "/api/base/baseApi/querysettlement")
    CommonResponse<SettlementPerioddetailVO> querysettlement(@RequestParam(value = "month") String month,@RequestParam(value = "orgId") String orgId);
}

==> ejc-lz-api-3.0.0-20220530.062856-119-sources.jar: com/ejianc/business/base/bases/api/BaseApi.java <==
package com.ejianc.business.base.bases.api;

import com.ejianc.business.base.bases.hystrix.BaseHystrix;
import com.ejianc.business.base.bases.vo.*;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name= "ejc-lz-web", url="${common.env.feign-client-url}", path="ejc-lz-web", fallback = BaseHystrix.class)
public interface BaseApi {
    @PostMapping("/api/base/baseApi/getshippersinfo")
    CommonResponse<ShippersInfoApiVO> getShippersInfo(@RequestParam(value = "carCode") String carCode,@RequestParam(value = "orgId") Long orgId);
    @GetMapping("/api/base/baseApi/updatestatus")
    CommonResponse updatestatus(@RequestParam(value = "vehicleId") Long vehicleId,@RequestParam(value = "status") Integer status);
    @GetMapping(value = "/api/base/baseApi/querymaterialdetail")
    CommonResponse<MaterialVO> querymaterialdetail(Long id);
    @GetMapping(value = "/api/base/baseApi/queryproductdetail")
    CommonResponse<ProductVO> queryproductdetail(Long id);
    @PostMapping(value = "/api/base/baseApi/querysettlement")
    CommonResponse<SettlementPerioddetailVO> querysettlement(@RequestParam(value = "month") String month,@RequestParam(value = "orgId") String orgId);
    @PostMapping(value = "/api/base/baseApi/queryunit")
    List<UnitVO> queryUnit(String orgId);
}
